@@ -33,7 +33,6 @@ from magnum.common import clients
 from magnum.common import exception
 from magnum.common import name_generator
 from magnum.common import policy
-from magnum.i18n import _LW
 from magnum import objects
 from magnum.objects import fields
 
@@ -90,6 +89,9 @@ class Bay(base.APIBase):
     master_count = wsme.wsattr(wtypes.IntegerType(minimum=1), default=1)
     """The number of master nodes for this bay. Default to 1 if not set"""
 
+    docker_volume_size = wtypes.IntegerType(minimum=1)
+    """The size in GB of the docker volume"""
+
     bay_create_timeout = wsme.wsattr(wtypes.IntegerType(minimum=0), default=60)
     """Timeout for creating the bay in minutes. Default to 60 if not set"""
 
@@ -172,6 +174,7 @@ class Bay(base.APIBase):
     def _convert_with_links(bay, url, expand=True):
         if not expand:
             bay.unset_fields_except(['uuid', 'name', 'baymodel_id',
+                                     'docker_volume_size',
                                      'node_count', 'status',
                                      'bay_create_timeout', 'master_count',
                                      'stack_id'])
@@ -195,6 +198,7 @@ class Bay(base.APIBase):
                      baymodel_id='4a96ac4b-2447-43f1-8ca6-9fd6f36d146d',
                      node_count=2,
                      master_count=1,
+                     docker_volume_size=1,
                      bay_create_timeout=15,
                      stack_id='49dc23f5-ffc9-40c3-9d34-7be7f9e34d63',
                      status=fields.ClusterStatus.CREATE_COMPLETE,
@@ -355,9 +359,9 @@ class BaysController(base.Controller):
                 bay.stack_id, nested_depth=2, filters=filters)
         except Exception as e:
             failed_resources = []
-            LOG.warning(_LW("Failed to retrieve failed resources for "
-                            "bay %(bay)s from Heat stack %(stack)s "
-                            "due to error: %(e)s"),
+            LOG.warning("Failed to retrieve failed resources for "
+                        "bay %(bay)s from Heat stack %(stack)s "
+                        "due to error: %(e)s",
                         {'bay': bay.uuid, 'stack': bay.stack_id, 'e': e},
                         exc_info=True)
 
@@ -416,6 +420,10 @@ class BaysController(base.Controller):
         baymodel = objects.ClusterTemplate.get_by_uuid(context,
                                                        bay.baymodel_id)
 
+        # If docker_volume_size is not present, use baymodel value
+        if bay.docker_volume_size == wtypes.Unset:
+            bay.docker_volume_size = baymodel.docker_volume_size
+
         bay_dict = bay.as_dict()
         bay_dict['keypair'] = baymodel.keypair_id
         attr_validator.validate_os_resources(context, baymodel.as_dict(),
@@ -425,7 +433,7 @@ class BaysController(base.Controller):
         bay_dict['project_id'] = context.project_id
         bay_dict['user_id'] = context.user_id
         # NOTE(yuywz): We will generate a random human-readable name for
-        # bay if the name is not spcified by user.
+        # bay if the name is not specified by user.
         name = bay_dict.get('name') or self._generate_name_for_bay(context)
         bay_dict['name'] = name
         bay_dict['coe_version'] = None
