@@ -64,7 +64,7 @@ class BayModel(base.APIBase):
 
     keypair_id = wsme.wsattr(wtypes.StringType(min_length=1, max_length=255),
                              mandatory=True)
-    """The name or id of the nova ssh keypair"""
+    """The name of the nova ssh keypair"""
 
     external_network_id = wtypes.StringType(min_length=1, max_length=255)
     """The external network to attach to the Bay"""
@@ -345,7 +345,7 @@ class BayModelsController(base.Controller):
                 raise exception.ClusterTemplatePublishDenied()
 
         # NOTE(yuywz): We will generate a random human-readable name for
-        # baymodel if the name is not spcified by user.
+        # baymodel if the name is not specified by user.
         arg_name = baymodel_dict.get('name')
         name = arg_name or self._generate_name_for_baymodel(context)
         baymodel_dict['name'] = name
