@@ -26,7 +26,6 @@ from oslo_log import log as logging
 from magnum.common import exception
 from magnum.common.x509 import validator
 import magnum.conf
-from magnum.i18n import _LE
 
 LOG = logging.getLogger(__name__)
 
@@ -189,7 +188,7 @@ def sign(csr, issuer_name, ca_key, ca_key_password=None,
         try:
             csr = x509.load_pem_x509_csr(csr, backend=default_backend())
         except ValueError:
-            LOG.exception(_LE("Received invalid csr {0}.").format(csr))
+            LOG.exception("Received invalid csr {0}.".format(csr))
             raise exception.InvalidCsr(csr=csr)
 
     term_of_validity = CONF.x509.term_of_validity
