@@ -44,17 +44,21 @@ MASTER_HOSTNAME=${MASTER_HOSTNAME:-}
 if [[ -n "${MASTER_HOSTNAME}" ]]; then
     sans="${sans},DNS:${MASTER_HOSTNAME}"
 fi
+
+if [[ -n "${ETCD_LB_VIP}" ]]; then
+    sans="${sans},IP:${ETCD_LB_VIP}"
+fi
+
 sans="${sans},IP:127.0.0.1"
 
 KUBE_SERVICE_IP=$(echo $PORTAL_NETWORK_CIDR | awk 'BEGIN{FS="[./]"; OFS="."}{print $1,$2,$3,$4 + 1}')
 
 sans="${sans},IP:${KUBE_SERVICE_IP}"
 
-cert_dir=/srv/kubernetes
-cert_conf_dir=${cert_dir}/conf
+sans="${sans},DNS:kubernetes,DNS:kubernetes.default,DNS:kubernetes.default.svc,DNS:kubernetes.default.svc.cluster.local"
 
+cert_dir=/etc/kubernetes/certs
 mkdir -p "$cert_dir"
-mkdir -p "$cert_conf_dir"
 
 CA_CERT=$cert_dir/ca.crt
 SERVER_CERT=$cert_dir/server.crt
@@ -93,13 +97,13 @@ curl -k -X GET \
     $MAGNUM_URL/certificates/$CLUSTER_UUID | python -c 'import sys, json; print json.load(sys.stdin)["pem"]' > ${CA_CERT}
 
 # Create config for server's csr
-cat > ${cert_conf_dir}/server.conf <<EOF
+cat > ${cert_dir}/server.conf <<EOF
 [req]
 distinguished_name = req_distinguished_name
 req_extensions     = req_ext
 prompt = no
 [req_distinguished_name]
-CN = kubernetes.invalid
+CN = kubernetes.default.svc
 [req_ext]
 subjectAltName = ${sans}
 extendedKeyUsage = clientAuth,serverAuth
@@ -112,7 +116,7 @@ openssl req -new -days 1000 \
         -key "${SERVER_KEY}" \
         -out "${SERVER_CSR}" \
         -reqexts req_ext \
-        -config "${cert_conf_dir}/server.conf"
+        -config "${cert_dir}/server.conf"
 
 # Send csr to Magnum to have it signed
 csr_req=$(python -c "import json; fp = open('${SERVER_CSR}'); print json.dumps({'cluster_uuid': '$CLUSTER_UUID', 'csr': fp.read()}); fp.close()")
