@@ -11,6 +11,4 @@ UUID=`uuidgen`
 
 data=$(echo '{"status": "'${STATUS}'", "reason": "'$REASON'", "data": "'${DATA}'", "id": "'$UUID'"}')
 
-curl -k -i -X POST -H "Content-Type: application/json" -H "X-Auth-Token: $WAIT_HANDLE_TOKEN" \
-    --data-binary "$data" \
-    "$WAIT_HANDLE_ENDPOINT"
+sh -c "${WAIT_CURL} --data-binary '${data}'"
