@@ -109,7 +109,11 @@ class K8sTemplateDefinition(template_def.BaseTemplateDefinition):
                       'flannel_network_subnetlen',
                       'system_pods_initial_delay',
                       'system_pods_timeout',
-                      'admission_control_list']
+                      'admission_control_list',
+                      'prometheus_monitoring',
+                      'grafana_admin_passwd',
+                      'kube_dashboard_enabled',
+                      'etcd_volume_size']
 
         for label in label_list:
             extra_params[label] = cluster_template.labels.get(label)
