@@ -79,7 +79,7 @@ class ClusterTemplateTest(base.BaseTempestTest):
 
     @testtools.testcase.attr('positive')
     def test_create_get_public_cluster_template(self):
-        gen_model = datagen.valid_swarm_cluster_template(is_public=True)
+        gen_model = datagen.valid_swarm_mode_cluster_template(is_public=True)
         self.assertRaises(
             exceptions.Forbidden,
             self.cluster_template_client.post_cluster_template, gen_model)
