@@ -33,7 +33,6 @@ from kubernetes.client.apis import core_v1_api
 
 from magnum.common.utils import rmtree_without_raise
 import magnum.conf
-from magnum.i18n import _LI
 from magnum.tests.functional.common import base
 from magnum.tests.functional.common import utils
 from magnumclient.common.apiclient import exceptions
@@ -134,7 +133,7 @@ class BaseMagnumClient(base.BaseMagnumTest):
 
         def _check_status():
             status = cls.cs.clusters.get(cluster.uuid).status
-            cls.LOG.debug("Cluster status is %s" % status)
+            cls.LOG.debug("Cluster status is %s", status)
             if status in wait_status:
                 return False
             elif status in finish_status:
@@ -264,6 +263,24 @@ extendedKeyUsage = clientAuth
         cls.cluster = cls._create_cluster(cls.__name__,
                                           cls.cluster_template.uuid)
         if not cls.cluster_template_kwargs.get('tls_disabled', False):
+            # NOTE (wangbo) with multiple mangum-conductor processes, client
+            # ca files should be created after completion of cluster ca_cert
+            try:
+                cls._wait_on_status(
+                    cls.cluster,
+                    [None, "CREATE_IN_PROGRESS"],
+                    ["CREATE_FAILED", "CREATE_COMPLETE"],
+                    timeout=cls.cluster_complete_timeout
+                )
+            except Exception:
+                # copy logs if setUpClass fails, may be this will not work
+                # as master_address, node_address would not be available, if
+                # not we can get that from nova
+                if cls.copy_logs:
+                    cls.copy_logs_handler(
+                        cls._get_nodes,
+                        cls.cluster_template.coe,
+                        'default')
             cls._create_tls_ca_files(cls.config_contents)
 
     @classmethod
@@ -290,8 +307,9 @@ extendedKeyUsage = clientAuth
 
         self.useFixture(fixtures.Timeout(test_timeout, gentle=True))
 
+        # Copy cluster nodes logs
         if self.copy_logs:
-            self.addOnException(
+            self.addCleanup(
                 self.copy_logs_handler(
                     self._get_nodes,
                     self.cluster_template.coe,
@@ -301,11 +319,11 @@ extendedKeyUsage = clientAuth
     def _get_nodes(self):
         nodes = self._get_nodes_from_cluster()
         if not [x for x in nodes if x]:
-            self.LOG.info(_LI("the list of nodes from cluster is empty"))
+            self.LOG.info("the list of nodes from cluster is empty")
             nodes = self._get_nodes_from_stack()
             if not [x for x in nodes if x]:
-                self.LOG.info(_LI("the list of nodes from stack is empty"))
-        self.LOG.info(_LI("Nodes are: %s"), nodes)
+                self.LOG.info("the list of nodes from stack is empty")
+        self.LOG.info("Nodes are: %s", nodes)
         return nodes
 
     def _get_nodes_from_cluster(self):
@@ -323,6 +341,10 @@ extendedKeyUsage = clientAuth
             output_keys = ["kube_masters", "kube_minions"]
         elif self.cluster_template.coe == "swarm":
             output_keys = ["swarm_masters", "swarm_nodes"]
+        elif self.cluster_template.coe == "swarm-mode":
+            output_keys = ["swarm_primary_master",
+                           "swarm_secondary_masters",
+                           "swarm_nodes"]
         elif self.cluster_template.coe == "mesos":
             output_keys = ["mesos_master", "mesos_slaves"]
 
@@ -411,10 +433,10 @@ class BaseK8sTest(ClusterTest):
     def _is_api_ready(self):
         try:
             self.k8s_api.list_node()
-            self.LOG.info(_LI("API is ready."))
+            self.LOG.info("API is ready.")
             return True
         except Exception:
-            self.LOG.info(_LI("API is not ready yet."))
+            self.LOG.info("API is not ready yet.")
             return False
 
     def test_pod_apis(self):
