@@ -48,7 +48,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'registry_enabled': False,
             'server_type': 'vm',
             'network_driver': 'network_driver',
-            'labels': {'flannel_network_cidr': '10.101.0.0/16',
+            'labels': {'docker_volume_type': 'lvmdriver-1',
+                       'flannel_network_cidr': '10.101.0.0/16',
                        'flannel_network_subnetlen': '26',
                        'flannel_backend': 'vxlan',
                        'rexray_preempt': 'False',
@@ -61,6 +62,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'cluster_template_id': 'xx-xx-xx-xx',
             'keypair': 'keypair_id',
+            'docker_volume_size': 20,
             'name': 'cluster1',
             'stack_id': 'xx-xx-xx-xx',
             'api_address': '172.17.2.3',
@@ -150,7 +152,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_version': 'fake-version',
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
-            'rexray_preempt': 'False'
+            'rexray_preempt': 'False',
+            'docker_volume_type': 'lvmdriver-1'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -225,7 +228,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_version': 'fake-version',
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
-            'rexray_preempt': 'False'
+            'rexray_preempt': 'False',
+            'docker_volume_type': 'lvmdriver-1'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -247,7 +251,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
                         'docker_volume_size', 'fixed_network', 'http_proxy',
                         'https_proxy', 'no_proxy', 'network_driver',
                         'master_flavor_id', 'docker_storage_driver',
-                        'volume_driver', 'rexray_preempt', 'fixed_subnet']
+                        'volume_driver', 'rexray_preempt', 'fixed_subnet',
+                        'docker_volume_type']
         for key in not_required:
             self.cluster_template_dict[key] = None
         self.cluster_dict['discovery_url'] = 'https://discovery.etcd.io/test'
@@ -290,12 +295,14 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'auth_url': 'http://192.168.10.10:5000/v3',
             'swarm_version': 'fake-version',
             'swarm_strategy': u'spread',
-            'rexray_preempt': 'False'
+            'rexray_preempt': 'False',
+            'docker_volume_type': 'lvmdriver-1',
+            'docker_volume_size': 20,
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
             ['../../common/templates/environments/with_private_network.yaml',
-             '../../common/templates/environments/no_volume.yaml',
+             '../../common/templates/environments/with_volume.yaml',
              '../../common/templates/environments/no_master_lb.yaml'],
             env_files)
 
@@ -359,7 +366,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_version': 'fake-version',
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
-            'rexray_preempt': 'False'
+            'rexray_preempt': 'False',
+            'docker_volume_type': 'lvmdriver-1'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -429,7 +437,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_version': 'fake-version',
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
-            'rexray_preempt': 'False'
+            'rexray_preempt': 'False',
+            'docker_volume_type': 'lvmdriver-1'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
